@@ -11,16 +11,11 @@ use strict;
 use warnings;
 
 package DBIx::TableLoader;
-{
-  $DBIx::TableLoader::VERSION = '1.100';
-}
-# git description: v1.003-5-gb3c3fb7
+# git description: v1.100-1-g8e5d9b8
 
-BEGIN {
-  $DBIx::TableLoader::AUTHORITY = 'cpan:RWSTAUNER';
-}
+our $AUTHORITY = 'cpan:RWSTAUNER';
 # ABSTRACT: Easily load a database table from a data set
-
+$DBIx::TableLoader::VERSION = '1.101';
 use Carp qw(croak);
 #use DBI 1.13 (); # oldest DBI on CPAN as of 2011-02-15; Has SQL_LONGVARCHAR
 use Try::Tiny 0.09;
@@ -441,7 +436,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Randy Stauner ACKNOWLEDGEMENTS CSV SQLite PostgreSQL MySQL TODO arrayrefs
 cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc
@@ -453,7 +448,9 @@ DBIx::TableLoader - Easily load a database table from a data set
 
 =head1 VERSION
 
-version 1.100
+version 1.101
+
+=for test_synopsis my (@connection_args, $dbh, $data);
 
 =head1 SYNOPSIS
 
@@ -752,8 +749,6 @@ however other checks may be added in the future.
 Subclasses can overwrite this to define their own validations
 (though calling the original (superclass method) is recommended).
 
-=for test_synopsis my (@connection_args, $dbh, $data);
-
 =head1 OPTIONS
 
 This module is very [excessively] configurable.
@@ -1091,58 +1086,18 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/DBIx-TableLoader>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-TableLoader>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/DBIx-TableLoader>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/D/DBIx-TableLoader>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=DBIx-TableLoader>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=DBIx::TableLoader>
+L<https://metacpan.org/release/DBIx-TableLoader>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-dbix-tableloader at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-TableLoader>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=DBIx-TableLoader>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -1156,6 +1111,22 @@ L<https://github.com/rwstauner/DBIx-TableLoader>
 
 Randy Stauner <rwstauner@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Randy Stauner
+
+=over 4
+
+=item *
+
+Randy Stauner <randy@magnificent-tears.com>
+
+=item *
+
+Randy Stauner <randy@r4s6.net>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Randy Stauner.
